@@ -800,7 +800,17 @@ void Titraqform::setupEditlay(void)
     QToolTip::add(m_pEndtime, trUtf8("Task Ending Time"));
     m_pEditlayout->addWidget(m_pEndtime);                           // Finally add the end editor
 
-    // Make the amount selector
+    // Make the total time amount selector
+    m_pAmount = new QTimeEdit(m_pCenframe, "TotalAmount");
+    if (m_pAmount == NULL)                                          // Sanity check
+        throw Genexcept("Main window amount creation failed.");     // Spew errors
+
+    // Configure attributes
+    m_pAmount->setDisplay(QTimeEdit::Hours | QTimeEdit::Minutes);
+    m_pAmount->setAutoAdvance(true);
+    m_pAmount->setEnabled(false);
+
+/*    // Make the amount selector
     m_pAmount = new AmountBox(TITRAQ_MINAMOUNT, TITRAQ_MAXAMOUNT, TITRAQ_STEPAMOUNT, m_pCenframe, "Amount");
     if (m_pAmount == NULL)                                      // Sanity check
         throw Genexcept("Main window amount creation failed."); // Spew errors
@@ -809,7 +819,7 @@ void Titraqform::setupEditlay(void)
     m_pAmount->setButtonSymbols(QSpinBox::PlusMinus);
     m_pAmount->setSuffix(trUtf8(" Mins"));
     m_pAmount->setEnabled(false);
-//    m_pAmount->setSpecialValueText(trUtf8("In progress"));
+//    m_pAmount->setSpecialValueText(trUtf8("In progress"));*/
 
     // Whatsthis info for the amount editor
     const char *kszAmount = "Edit the <em>task amount</em> by clicking on "
@@ -880,7 +890,7 @@ void Titraqform::setupEditlay(void)
     connect(m_pDateedit, SIGNAL(valueChanged(const QDate &)), this, SLOT(validateData(void)));
     connect(m_pStarttime, SIGNAL(valueChanged(const QTime &)), this, SLOT(validateData(void)));
     connect(m_pEndtime, SIGNAL(valueChanged(const QTime &)), this, SLOT(validateData(void)));
-    connect(m_pAmount, SIGNAL(valueChanged(const QString &)), this, SLOT(validateData(void)));
+    connect(m_pAmount, SIGNAL(valueChanged(const QTime &)), this, SLOT(validateData(void)));
     connect(m_pTasks, SIGNAL(textChanged(const QString &)), this, SLOT(validateData(void)));
     connect(m_pRemark, SIGNAL(textChanged(const QString &)), this, SLOT(validateData(void)));
 
@@ -893,7 +903,7 @@ void Titraqform::setupEditlay(void)
     connect(m_pDateedit, SIGNAL(valueChanged(const QDate &)), this, SLOT(updateDate(const QDate &)));
     connect(m_pStarttime, SIGNAL(valueChanged(const QTime &)), this, SLOT(updateStart(const QTime &)));
     connect(m_pEndtime, SIGNAL(valueChanged(const QTime &)), this, SLOT(updateFinish(const QTime &)));
-    connect(m_pAmount, SIGNAL(valueChanged(const QString &)), this, SLOT(updateAmount(const QString &)));
+    connect(m_pAmount, SIGNAL(valueChanged(const QTime &)), this, SLOT(updateAmount(const QTime &)));
     connect(m_pTasks, SIGNAL(textChanged(const QString &)), this, SLOT(updateTask(const QString &)));
     connect(m_pRemark, SIGNAL(textChanged(const QString &)), this, SLOT(updateRemark(const QString &)));
 
@@ -902,7 +912,7 @@ void Titraqform::setupEditlay(void)
     connect(m_pDateedit, SIGNAL(valueChanged(const QDate &)), this, SLOT(calcCrc(void)));
     connect(m_pStarttime, SIGNAL(valueChanged(const QTime &)), this, SLOT(calcCrc(void)));
     connect(m_pEndtime, SIGNAL(valueChanged(const QTime &)), this, SLOT(calcCrc(void)));
-    connect(m_pAmount, SIGNAL(valueChanged(const QString &)), this, SLOT(calcCrc(void)));
+    connect(m_pAmount, SIGNAL(valueChanged(const QTime &)), this, SLOT(calcCrc(void)));
     connect(m_pTasks, SIGNAL(textChanged(const QString &)), this, SLOT(calcCrc(void)));
     connect(m_pRemark, SIGNAL(textChanged(const QString &)), this, SLOT(calcCrc(void)));
 }
