@@ -46,7 +46,9 @@
 #include "as_generic.h"         // Generic classes
 #include "as_uuid.h"            // UUID classes
 #include "as_datedit.h"         // Derived from QDateEdit
-#include "as_crc.h"             // Useful qualistring class
+#include "as_crc.h"             // Useful Qualistring class
+#include "as_panel.h"           // For Prefpanel class
+#include "as_sfile.h"           // For Simplefile class
 
 // RPC headers
 #ifdef HAVE_ESOAP
@@ -430,8 +432,7 @@ void Titraqform::openDoc(void)
 void Titraqform::saveFile(void)
 {
     QString Fname;
-    QFile Filevents, Filebak;
-    QTextStream Streamevents, Streambak;
+    Simplefile Filevents;
 
     try {
         Fname = *this->getFilename();
@@ -448,21 +449,9 @@ void Titraqform::saveFile(void)
             }
         }
 
-        Filevents.setName(Fname); // Construct a file to back up and write
-
-        // Make a backup before overwriting
-        if (Filevents.exists()) {
-            Filevents.open(IO_ReadOnly);
-            Filebak.setName(Fname + ".bak");
-            Filebak.open(IO_WriteOnly);
-            Streamevents.setDevice(&Filevents);
-            Streambak.setDevice(&Filebak);
-            Streambak << Streamevents.read();
-            Filevents.close();
-            Filebak.close();
-        }
-
-        this->saveData(Filevents); // Pass to helper method
+        Filevents.setName(Fname);   // Construct a file to write
+        Filevents.makeBackup();     // Back up to filename.bak
+        this->saveData(Filevents);  // Pass to helper method
     }
     catch (Genexcept& Genex) {
         Genex.reportErr();
@@ -882,7 +871,6 @@ void Titraqform::updEdit(int nRow, int nCol)
 //        QRegExp Shorten("/(\\w+)$");    // For stripping prefix off the current task
 //        Texttask.remove(0, Shorten.search(Texttask) + 1); // Strip leading slash
 
-        m_pAmount->setText(Textamount);
         m_pRemark->setText(Textremark);
         m_pTasks->setCurrentText(Texttask);
 
@@ -913,12 +901,12 @@ void Titraqform::updEdit(int nRow, int nCol)
         // Amount time not suitable for empty string text
         if (Textamount == ".") {
             int nDifference = m_pStarttime->time().secsTo(m_pEndtime->time());
-            m_pAmount->setText(QTime(0, 0).addSecs(nDifference).toString("hh:mm"));
+            m_pAmount->setTime(QTime(0, 0).addSecs(nDifference));
         }
         else if (Textamount.isEmpty())
-            m_pAmount->setText(QString("00:00"));
+            m_pAmount->setTime(QTime::QTime(0, 0));
         else
-            m_pAmount->setText(Textamount);
+            m_pAmount->setTime(QTime::fromString(Textamount, Qt::ISODate));
     }
 }
 
@@ -1066,10 +1054,9 @@ void Titraqform::updateFinish(const QTime &Finishup)
 //
 // Update the current amount column item
 //
-void Titraqform::updateAmount(const QString &Amountup)
+void Titraqform::updateAmount(const QTime &Amountup)
 {
-    // Ignore incoming data and use widget managed data because its easier
-    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXAMOUNT, m_pAmount->text());
+    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXAMOUNT, Amountup.toString("hh:mm"));
 }
 
 //
@@ -1105,7 +1092,7 @@ void Titraqform::confirmEdit(void)
     m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXDATE, m_pDateedit->date().toString(Qt::ISODate));
     m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXSTART, m_pStarttime->time().toString(Qt::ISODate));
     m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXFINISH, m_pEndtime->time().toString(Qt::ISODate));
-    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXAMOUNT, m_pAmount->text());
+    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXAMOUNT, m_pAmount->time().toString(Qt::ISODate));
 
     // Specially handle task fields
     pTask = static_cast<RtTableItem *>(m_pMaintable->item(m_pMaintable->currentRow(), TITRAQ_IDXTASK));
@@ -1119,8 +1106,17 @@ void Titraqform::confirmEdit(void)
 //
 void Titraqform::configPrefs(void)
 {
-    Prototype Unimp;
-    Unimp.doMbox();
+    Prefpanel *pUserpanel = NULL;
+
+    // Create a new preferences panel window
+    pUserpanel = new Prefpanel(this, "Userprefpanel");
+
+    // Handle panel modality
+    if (pUserpanel->exec() == QDialog::Accepted) {
+//        pvData = pUserpanel->getData();
+//        setPrefs(pvData);
+    }
+    delete pUserpanel;
 }
 
 //
